[![Build Status](https://travis-ci.org/OCA/connector.svg?branch=9.0)](https://travis-ci.org/OCA/connector)
[![Coverage Status](https://coveralls.io/repos/OCA/connector/badge.png?branch=9.0)](https://coveralls.io/r/OCA/connector?branch=9.0)


Odoo Connector Modules
======================

*Odoo Connector is a powerful framework to develop any kind of bi-directional connector between Odoo (Open Source ERP formerly OpenERP) and any other software or service.*

This Odoo add-on has a modular and generic core, with the ability to be extended with additional modules for new features or customizations.

Feel free to subscribe on the mailing list (its name is 'Connectors'):
https://odoo-community.org/groups

Documentation:
http://www.odoo-connector.com

[//]: # (addons)

Available addons
----------------
addon | version | summary
--- | --- | ---
[connector](connector/) | 9.0.1.0.3 | Connector
[connector_base_product](connector_base_product/) | 9.0.1.0.0 | Connector Base Product
[connector_job_subscribe](connector_job_subscribe/) | 9.0.1.0.0 | Connector

[//]: # (end addons)

Translation Status
------------------
[![Transifex Status](https://www.transifex.com/projects/p/OCA-connector-9-0/chart/image_png)](https://www.transifex.com/projects/p/OCA-connector-9-0)
